@@ -14,10 +14,12 @@ from quark.core.parallelquark import ParallelQuark
 from quark.core.quark import Quark
 from quark.core.struct.ruleobject import RuleObject
 from quark.logo import logo
+from quark.rulegeneration import RuleGeneration
 from quark.utils.colors import yellow
 from quark.utils.graph import select_label_menu, show_comparison_graph
 from quark.utils.pprint import print_info, print_success, print_warning
 from quark.utils.weight import Weight
+from quark.webreport.generate import ReportGenerator
 
 logo()
 
@@ -45,6 +47,13 @@ logo()
     type=click.Path(exists=False, file_okay=True, dir_okay=False),
     required=False,
 )
+@click.option(
+    "-w",
+    "--webreport",
+    help="Generate web report",
+    type=click.Path(exists=False, file_okay=True, dir_okay=False),
+    required=False,
+)
 @click.option(
     "-a",
     "--apk",
@@ -113,6 +122,13 @@ logo()
     required=False,
     is_flag=True,
 )
+@click.option(
+    "--generate-rule",
+    "rule_generation",
+    help="Generate rules and output to given directory",
+    type=click.Path(exists=True, file_okay=False, dir_okay=True),
+    required=False,
+)
 @click.option(
     "--core-library",
     "core_library",
@@ -133,9 +149,11 @@ logo()
 def entry_point(
     summary,
     detail,
+    rule_generation,
     apk,
     rule,
     output,
+    webreport,
     graph,
     classification,
     threshold,
@@ -165,8 +183,9 @@ def entry_point(
         rule_path_list = [rule_filter]
     else:
         rule_path_list = [
-            os.path.join(rule, file)
-            for file in os.listdir(rule)
+            os.path.join(dir_path, file)
+            for dir_path, _, file_list in os.walk(rule)
+            for file in file_list
             if file.endswith("json")
         ]
 
@@ -355,9 +374,19 @@ def entry_point(
         if graph:
             data.show_call_graph()
 
+    if rule_generation:
+        generator = RuleGeneration(apk[0], rule_generation)
+
+        if webreport:
+            if ".html" not in webreport:
+                webreport = f"{webreport}.html"
+            webreport_file = os.path.join(rule_generation, webreport)
+            generator.generate_rule(web_editor=webreport_file)
+        else:
+            generator.generate_rule()
+
     # Show JSON report
     if output:
-
         if isinstance(data, ParallelQuark):
             data.apply_rules(rule_buffer_list)
 
@@ -373,6 +402,23 @@ def entry_point(
             json.dump(json_report, file, indent=4)
             file.close()
 
+    # Generate web report
+    if webreport:
+        if summary or detail:
+            for rule_checker in tqdm(rule_buffer_list):
+                data.generate_json_report(rule_checker)
+
+            json_report = data.get_json_report()
+            report_html = ReportGenerator(
+                json_report).get_analysis_report_html()
+
+            if ".html" not in webreport:
+                webreport = f"{webreport}.html"
+
+            with open(webreport, "w") as file:
+                file.write(report_html)
+                file.close()
+
     if list:
 
         if list == "all":
